<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:xs="http://www.w3.org/2001/XMLSchema"
    xmlns:tei="http://www.tei-c.org/ns/1.0"
    xmlns="http://www.w3.org/1999/xhtml"
    exclude-result-prefixes="xs"
    version="2.0" xpath-default-namespace="http://sub.uni-goettingen.de/edxml#">
    
    <xsl:template match="facsimile">
        <div class="facsimile section" 
            id="{if(@xml:id) then (@xml:id) else ('facs_'||generate-id(.))}">
            <xsl:apply-templates />
        </div>
    </xsl:template>
    
    <xsl:template match="surface">
        <div class="surface" 
            id="{if(@xml:id) then (@xml:id) else ('surf_'||generate-id(.))}">
            <xsl:apply-templates />
        </div>
    </xsl:template>
    
    <xsl:template match="column">
        <xsl:variable name="nr" select="if(@n) then(@n) else(count(preceding::column)+1)"/>
        <xsl:variable name="id" select="if(@xml:id) then (@xml:id) else ('colu_'||generate-id(.))"/>
        <div class="column" 
            id="{$id}"
            data-n="{$nr}">
            <xsl:apply-templates />
        </div>
    </xsl:template>
    
    <xsl:template match="line[not(@n)]|surface//note">
        <div class="note" 
            id="{if(@xml:id) then (@xml:id) else ('line_'||generate-id(.))}">
            <xsl:apply-templates />
        </div>
    </xsl:template>
    
    <xsl:template match="line[@n]">
        <xsl:variable name="nr" select="@n"/>
        <xsl:variable name="auto-nr" select="if($nr) then($nr) else(count(preceding::line)+1)"/>
        <xsl:variable name="id" select="if(@xml:id) then (@xml:id) else ('line_'||generate-id(.))"/>
        <div class="line" 
            id="{$id}">
            <a href="#{$id}" class="line-anchor">
                <span>
                    <xsl:choose>
                        <xsl:when test="@n">
                            <xsl:attribute name="class">line-nr explicit</xsl:attribute>
                        </xsl:when>
                        <xsl:otherwise>
                            <xsl:attribute name="class">line-nr calculated</xsl:attribute>
                        </xsl:otherwise>
                    </xsl:choose>
                    <xsl:value-of select="$auto-nr"/>
                </span>
            </a>
            <span class="line-body">
                <xsl:apply-templates />
            </span>
        </div>
    </xsl:template>
    
    
    <!-- LINE-PARTS -->
    <xsl:template match="g[not(@cert)]">        
        <span class="g" 
            id="{if(@xml:id) then (@xml:id) else ('part_'||generate-id(.))}">
            <xsl:apply-templates/>
        </span>    
    </xsl:template>
    
    <xsl:template match="g[@cert]">        
        <span class="g"
            data-cert="{@cert}"
            id="{if(@xml:id) then (@xml:id) else ('part_'||generate-id(.))}">
            <xsl:apply-templates/>
        </span>    
    </xsl:template>
    
    <xsl:template match="metamark[contains(@rend, 'Line') or contains(@rend, 'line')]">
        <xsl:variable name="rend" select="@rend"/>
        <hr class="metamark-line {$rend}" data-rend="{$rend}"/>
    </xsl:template>
    
    <xsl:template match="line//part">
        <span class="part" 
            id="{if(@xml:id) then (@xml:id) else ('part_'||generate-id(.))}">
            <xsl:apply-templates />
        </span>
    </xsl:template>
    
    <xsl:template match="line//seg">
        <span class="seg" 
            id="{if(@xml:id) then (@xml:id) else ('part_'||generate-id(.))}">
            <xsl:apply-templates />
        </span>
    </xsl:template>
    
</xsl:stylesheet>